==> jc-1.4.0.tar.gz: java/awt/ColorPaintContext.h <==
// class java.awt.ColorPaintContext

// class file dependencies
// @dep_class 4bf5f7a763b65985 java_awt_ColorPaintContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_ColorPaintContext_H_
#define _JC_java_awt_ColorPaintContext_H_

// Forward structure declarations
struct _jc_java_awt_ColorPaintContext__24ColorRaster$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_awt_image_Raster$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_ColorPaintContext$sub_refs	_jc_java_awt_ColorPaintContext$sub_refs;
typedef struct _jc_java_awt_ColorPaintContext$sub_nonrefs	_jc_java_awt_ColorPaintContext$sub_nonrefs;
typedef struct _jc_java_awt_ColorPaintContext$refs	_jc_java_awt_ColorPaintContext$refs;
typedef struct _jc_java_awt_ColorPaintContext$nonrefs	_jc_java_awt_ColorPaintContext$nonrefs;
typedef struct _jc_java_awt_ColorPaintContext$object	_jc_java_awt_ColorPaintContext$object;

typedef const struct _jc_java_awt_ColorPaintContext$vmethods	_jc_java_awt_ColorPaintContext$vmethods;
typedef const struct _jc_java_awt_ColorPaintContext$vtable	_jc_java_awt_ColorPaintContext$vtable;
typedef const struct _jc_java_awt_ColorPaintContext$vtype	_jc_java_awt_ColorPaintContext$vtype;

// Constructors
extern void _jc_java_awt_ColorPaintContext$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *, jint);
extern void _jc_java_awt_ColorPaintContext$method$_init$7a5e65ba154b18a9(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *, struct _jc_java_awt_image_ColorModel$object *, jint);

// Virtual methods
extern void _jc_java_awt_ColorPaintContext$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *);
extern struct _jc_java_awt_image_ColorModel$object *_jc_java_awt_ColorPaintContext$method$getColorModel$c0873fe840f235f1(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *);
extern struct _jc_java_awt_image_Raster$object *_jc_java_awt_ColorPaintContext$method$getRaster$5ea6a5688e3ec18a(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_ColorPaintContext$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_java_awt_ColorPaintContext$method_info$getColorModel$c0873fe840f235f1;
extern _jc_method _jc_java_awt_ColorPaintContext$method_info$getRaster$5ea6a5688e3ec18a;

// Virtual methods structure
struct _jc_java_awt_ColorPaintContext$vmethods {
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *);
	struct _jc_java_awt_image_ColorModel$object	*(*getColorModel$c0873fe840f235f1)(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *);
	struct _jc_java_awt_image_Raster$object	*(*getRaster$5ea6a5688e3ec18a)(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_java_awt_ColorPaintContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_ColorPaintContext$vmethods	java_awt_ColorPaintContext;
};

// Vtype
struct _jc_java_awt_ColorPaintContext$vtype {
	_jc_type			type;
	_jc_java_awt_ColorPaintContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_ColorPaintContext$sub_refs {
	struct _jc_java_awt_image_ColorModel$object	*colorModel;
	struct _jc_java_awt_ColorPaintContext__24ColorRaster$object	*cachedRaster;
};

// Reference instance fields (object)
struct _jc_java_awt_ColorPaintContext$refs {
    _jc_java_awt_ColorPaintContext$sub_refs	java_awt_ColorPaintContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_ColorPaintContext$sub_nonrefs {
	jint	color;
};

// Non-reference instance fields (object)
struct _jc_java_awt_ColorPaintContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_ColorPaintContext$sub_nonrefs	java_awt_ColorPaintContext;
};

// Object instance structure
struct _jc_java_awt_ColorPaintContext$object {
	_jc_java_awt_ColorPaintContext$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_ColorPaintContext$vtype	*vtype;
	_jc_java_awt_ColorPaintContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_ColorPaintContext$vtype _jc_java_awt_ColorPaintContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_ColorPaintContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_ColorPaintContext$class_object;

#endif	/* _JC_java_awt_ColorPaintContext_H_ */

==> jc-1.4.6.tar.gz: java/awt/ColorPaintContext.h <==
// class java.awt.ColorPaintContext

// class file dependencies
// @dep_class 4bf5f7a763b65985 java_awt_ColorPaintContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_ColorPaintContext_H_
#define _JC_java_awt_ColorPaintContext_H_

// Forward structure declarations
struct _jc_java_awt_ColorPaintContext__24ColorRaster$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_awt_image_Raster$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_ColorPaintContext$sub_refs	_jc_java_awt_ColorPaintContext$sub_refs;
typedef struct _jc_java_awt_ColorPaintContext$sub_nonrefs	_jc_java_awt_ColorPaintContext$sub_nonrefs;
typedef struct _jc_java_awt_ColorPaintContext$refs	_jc_java_awt_ColorPaintContext$refs;
typedef struct _jc_java_awt_ColorPaintContext$nonrefs	_jc_java_awt_ColorPaintContext$nonrefs;
typedef struct _jc_java_awt_ColorPaintContext$object	_jc_java_awt_ColorPaintContext$object;

typedef const struct _jc_java_awt_ColorPaintContext$vmethods	_jc_java_awt_ColorPaintContext$vmethods;
typedef const struct _jc_java_awt_ColorPaintContext$vtable	_jc_java_awt_ColorPaintContext$vtable;
typedef const struct _jc_java_awt_ColorPaintContext$vtype	_jc_java_awt_ColorPaintContext$vtype;

// Constructors
extern void _jc_java_awt_ColorPaintContext$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_ColorPaintContext$method$_init$7a5e65ba154b18a9(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *, struct _jc_java_awt_image_ColorModel$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_ColorPaintContext$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_ColorModel$object *_jc_java_awt_ColorPaintContext$method$getColorModel$c0873fe840f235f1(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_Raster$object *_jc_java_awt_ColorPaintContext$method$getRaster$5ea6a5688e3ec18a(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_ColorPaintContext$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_java_awt_ColorPaintContext$method_info$getColorModel$c0873fe840f235f1;
extern _jc_method _jc_java_awt_ColorPaintContext$method_info$getRaster$5ea6a5688e3ec18a;

// Virtual methods structure
struct _jc_java_awt_ColorPaintContext$vmethods {
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_image_ColorModel$object	*(*getColorModel$c0873fe840f235f1)(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_image_Raster$object	*(*getRaster$5ea6a5688e3ec18a)(_jc_env *, struct _jc_java_awt_ColorPaintContext$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_ColorPaintContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_ColorPaintContext$vmethods	java_awt_ColorPaintContext;
};

// Vtype
struct _jc_java_awt_ColorPaintContext$vtype {
	_jc_type			type;
	_jc_java_awt_ColorPaintContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_ColorPaintContext$sub_refs {
	struct _jc_java_awt_image_ColorModel$object	*colorModel;
	struct _jc_java_awt_ColorPaintContext__24ColorRaster$object	*cachedRaster;
};

// Reference instance fields (object)
struct _jc_java_awt_ColorPaintContext$refs {
    _jc_java_awt_ColorPaintContext$sub_refs	java_awt_ColorPaintContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_ColorPaintContext$sub_nonrefs {
	jint	color;
};

// Non-reference instance fields (object)
struct _jc_java_awt_ColorPaintContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_ColorPaintContext$sub_nonrefs	java_awt_ColorPaintContext;
};

// Object instance structure
struct _jc_java_awt_ColorPaintContext$object {
	_jc_java_awt_ColorPaintContext$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_ColorPaintContext$vtype	*vtype;
	_jc_java_awt_ColorPaintContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_ColorPaintContext$vtype _jc_java_awt_ColorPaintContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_ColorPaintContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_ColorPaintContext$class_object;

#endif	/* _JC_java_awt_ColorPaintContext_H_ */
